package com.jz.manage.moduls.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.BasePageBean;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.manage.moduls.controller.finance.platForm.OrderCountInfoDto;
import com.jz.manage.moduls.controller.finance.platForm.PlatFormMoneyAndDepartDto;
import com.jz.manage.moduls.controller.finance.platForm.TradeDetilDto;
import com.jz.manage.moduls.controller.finance.platForm.TradeDetilRequest;
import com.jz.manage.moduls.mapper.PlatformTradeFlowInfoDao;
import com.jz.manage.moduls.service.PlatformTradeFlowInfoService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 平台交易流水(TPlatformTradeFlowInfo)表服务实现类
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:44
 */
@Service("platformTradeFlowInfoService")
@Transactional
public class PlatformTradeFlowInfoServiceImpl implements PlatformTradeFlowInfoService {

    @Autowired
    private PlatformTradeFlowInfoDao platformTradeFlowInfoDao;

    @Override
    public PlatFormMoneyAndDepartDto queryPlatFormMoneyAndDepart(Map map) throws Exception {
        return platformTradeFlowInfoDao.queryPlatFormMoneyAndDepart(map);
    }

    /*
     * 财务管理---我的订单
     * */
    @Override
    public PageInfoResponse<OrderCountInfoDto> findListOrderCount(BasePageBean pageBean, HttpServletRequest httpRequest) throws Exception {
        PageInfoResponse<OrderCountInfoDto> pageInfoResponse = new PageInfoResponse<>();

        Map param = new HashMap();
        //从session中获取平台用户id
        //SysUserDto user = (SysUserDto) SessionUtils.getUserCurrent(requset,"sysUser");
        //param.put("userId", user.getUserId());
        //param.put("pageNum", pageBean.getPageNum());
        //param.put("pageSize", pageBean.getPageSize());
        PageHelper.startPage(pageBean.getPageNum(), pageBean.getPageSize());
        List<OrderCountInfoDto> list = platformTradeFlowInfoDao.findListOrderCount(param);
        PageInfo<OrderCountInfoDto> pageInfo = new PageInfo<>(list);

        pageInfoResponse.setCode(Constants.SUCCESS_CODE);
        pageInfoResponse.setMessage("查询成功");
        pageInfoResponse.setData(pageInfo);
        return pageInfoResponse;
    }

    /*
     * 财务管理--交易明细
     * */
    @Override
    public PageInfoResponse<TradeDetilDto> findListFinanceTradeDetil(TradeDetilRequest tradeDetilRequest, HttpServletRequest httpRequest) throws Exception {
        PageInfoResponse<TradeDetilDto> pageInfoResponse = new PageInfoResponse<>();

        Map param = new HashMap();
        //从session中获取平台用户id
        //SysUserDto user = (SysUserDto) SessionUtils.getUserCurrent(requset,"sysUser");
        //param.put("userId", user.getUserId());
        //数据行业
        if (StringUtils.isNotEmpty(tradeDetilRequest.getCategoryId())) {
            param.put("categoryId", tradeDetilRequest.getCategoryId());
        }
        //订单方式
        if (StringUtils.isNotEmpty(tradeDetilRequest.getOrderMethod())) {
            param.put("orderMethod", tradeDetilRequest.getOrderMethod());
        }
        //企业名
        if (StringUtils.isNotEmpty(tradeDetilRequest.getDepartmentName())) {
            param.put("departmentName", tradeDetilRequest.getDepartmentName());
        }
        //数据名称
        if (StringUtils.isNotEmpty(tradeDetilRequest.getDataName())) {
            param.put("dataName", tradeDetilRequest.getDataName());
        }

        PageHelper.startPage(tradeDetilRequest.getPageNum(), tradeDetilRequest.getPageSize());
        List<TradeDetilDto> list = platformTradeFlowInfoDao.findListFinanceTradeDetil(param);
        PageInfo<TradeDetilDto> pageInfo = new PageInfo<>(list);

        pageInfoResponse.setCode(Constants.SUCCESS_CODE);
        pageInfoResponse.setMessage("查询成功");
        pageInfoResponse.setData(pageInfo);
        return pageInfoResponse;
    }
}